@@ -8,7 +8,7 @@ use Dancer2::Plugin;
 use Class::Load qw(try_load_class);
 use Session::Token;
 
-our $VERSION = '0.402';
+our $VERSION = '0.500';
 
 my $settings;
 
@@ -241,7 +241,7 @@ sub require_login {
 
     return sub {
         if (!$coderef || ref $coderef ne 'CODE') {
-            warn "Invalid require_login usage, please see docs";
+            $dsl->warning("Invalid require_login usage, please see docs");
         }
 
         my $user = logged_in_user($dsl);
@@ -331,6 +331,8 @@ sub _build_wrapper {
         }
 
         my $role_match;
+        # this is a private method and we should never need 'else'
+        # uncoverable branch false count:3
         if ($mode eq 'single') {
             for (user_roles($dsl)) {
                 $role_match++ and last if _smart_match($_, $require_role);
@@ -392,6 +394,31 @@ sub logged_in_user {
 }
 register logged_in_user => \&logged_in_user;
 
+
+=item get_user_details
+
+Returns a hashref of details of the specified user. The realm can optionally
+be specified as the second parameter. If the realm is not specified, each
+realm will be checked, and the first matching user will be returned.
+
+The details you get back will depend upon the authentication provider in use.
+
+=cut
+
+sub get_user_details {
+    my ($dsl, $username, $realm) = @_;
+
+    my @realms_to_check = $realm ? ($realm) : (keys %{ $settings->{realms} });
+
+    for my $realm (@realms_to_check) {
+        $dsl->app->log ( debug  => "Attempting to find user $username in realm $realm");
+        my $provider = auth_provider($dsl, $realm);
+        my $user = $provider->get_user_details($username, $realm);
+        $user and return $user;
+    }
+}
+register get_user_details => \&get_user_details;
+
 =item user_has_role
 
 Check if a user has the role named.
@@ -558,8 +585,9 @@ sub update_user {
     my $updated  = $provider->set_user_details($username, %update);
     my $request  = $dsl->app->request;
     my $session  = $dsl->app->session;
+    my $cur_user = $session->read('logged_in_user');
     $request->vars->{logged_in_user_hash} = $updated
-        if $username eq $session->read('logged_in_user');
+        if $cur_user && $cur_user eq $username;
     $updated;
 }
 register update_user => \&update_user;
@@ -1276,8 +1304,9 @@ sub _post_login_route {
         $app->redirect($app->params->{return_url} || $userhomepage);
     }
 
+    my $auth_realm = $app->app->request->param('realm');
     my ($success, $realm) = authenticate_user(
-        $app, $username, $password
+        $app, $username, $password, $auth_realm
     );
     if ($success) {
         $app->app->session->write(logged_in_user => $username);
