@@ -5,7 +5,7 @@ use base 'Dancer2::Plugin::Auth::Extensible::Provider::Base';
 use Authen::Simple::PAM;
 use Unix::Passwd::File;
 
-our $VERSION = '0.402';
+our $VERSION = '0.500';
 
 =head1 NAME
 
@@ -19,12 +19,13 @@ authenticates Linux/Unix system accounts.
 Uses L<Unix::Passwd::File> to read user details, and L<Authen::Simple::PAM> to
 perform authentication via PAM.
 
-The C<get_user_details> call for this provider will return information from the
-C<passwd> file - expect C<gecos>, C<gid>, C<uid>, C<home>, C<shell>, C<uid>.
-
 Unix group membership is used as a reasonable facsimile for roles - this seems
 sensible.
 
+=head1 METHODS
+
+=head2 authenticate_user $username, $password
+
 =cut
 
 sub authenticate_user {
@@ -32,7 +33,13 @@ sub authenticate_user {
     my $pam = Authen::Simple::PAM->new( service => 'login' );
     return $pam->authenticate($username, $password);
 }
-    
+
+=head2 get_user_details $username
+
+Returns information from the C<passwd> file - expect C<gecos>, C<gid>,
+C<uid>, C<home>, C<shell>, C<uid>.
+
+=cut
 
 sub get_user_details {
     my ($class, $username) = @_;
@@ -44,6 +51,10 @@ sub get_user_details {
     return $result->[2];
 }
 
+=head2 get_user_roles $username
+
+=cut
+
 sub get_user_roles {
     my ($class, $username) = @_;
     my $result = Unix::Passwd::File::get_user_groups(user => $username);
